#!/usr/bin/env python
from setuptools import setup
setup(
  name = 'cs.html',
  description = 'easy HTML and XHTML transcription',
  author = 'Cameron Simpson',
  author_email = 'cs@zip.com.au',
  version = '20160828',
  url = 'https://bitbucket.org/cameron_simpson/css/commits/all',
  classifiers = ['Programming Language :: Python', 'Programming Language :: Python :: 2', 'Programming Language :: Python :: 3', 'License :: OSI Approved :: GNU General Public License v3 (GPLv3)', 'Development Status :: 4 - Beta', 'Topic :: Software Development :: Libraries :: Python Modules', 'Intended Audience :: Developers', 'Operating System :: OS Independent'],
  install_requires = ['cs.logutils', 'cs.py3'],
  keywords = ['python2', 'python3'],
  long_description = 'HTML transcription functions.\n=============================\n\nMalformed markup is enraging. Therefore, when I must generate HTML I construct a token structure using natural Python objects (strings, lists, dicts) and use this module to transcribe them to syntacticly correct HTML. This also avoids lots of tedious and error prone entity escaping.\n\nA "token" in this scheme is:\n\n* a string: transcribed safely to HTML, eg "some text here"\n\n* an int or float: transcribed safely to HTML, eg 1 or 2.5.\n\n* a sequence: an HTML tag: element 0 is the tag name, element 1 (if a mapping) is the element attributes, any further elements are enclosed tokens, eg: [\'H1\', {\'align\': \'centre\'}, \'Heading Text\']\n\n  - because a string like "&foo" gets its "&" transcribed into the entity "&amp;", a single element list whose tag begins with "&" encodes an entity, example: ["&lt;"]\n\n* a preformed token object with .tag (a string) and .attrs (a mapping) attributes\n\nCore functions:\n---------------\n\n* ``transcribe(*tokens)``: a generator yielding strings comprising HTML\n\n* ``xtranscribe(*tokens)``: a generator yielding strings comprising XHTML\n\n* ``attrquote(s)``: quote the string ``s`` for use as a tag attribute according to HTML 4.01 section 3.2.2\n\n* ``nbsp(s)``: convert ``s`` to nonbreaking text: generator yielding tokens with whitespace converted to &nbsp; entities\n\nConvenience routines:\n---------------------\n\n* ``transcribe_s(*tokens)``: convert ``tokens`` into a string containing HTML\n\n* ``xtranscribe_s(*tokens)``: convert ``tokens`` into a string containing XHTML\n\nObsolete:\n---------\n* tok2s: transcribe tokens to a string; trivial wrapper for puttok\n* puttok: transcribe tokens to a file\n* text2s: transcribe a string to an HTML-safe string; trivial wrapper for puttext\n* puttext: transcribe a string as HTML-safe text to a file\n\nExample::\n\n  from cs.html import transcribe, transcribe_s, xtranscribe, puttok\n  [...]\n  table = [\'TABLE\', {\'width\': \'80%\'},\n           [\'TR\',\n            [\'TD\', \'a truism\'],\n            [\'TD\', \'1 < 2\']\n           ]\n           [\'TR\',\n            [\'TD\', \'a couple\'],\n            [\'TD\', \'A & B\']\n           ]\n          ]\n  prose_with_table = [\n            \'Here is a line with a line break.\', [\'BR\'],\n            \'Here is a trite table:\',\n            table,\n          ]\n  [...]\n  print(\'Here is the table\'s HTML:\', transcribe_s(table))\n  [...]\n  # write HTML tokens to a file\n  for s in transcribe([\'H1\', {\'align\': \'left\'}, \'Prose\'], *prose_with_table):\n    fp.write(s)\n  [...]\n  # write XHTML tokens to a file\n  for s in xtranscribe(*prose_with_table):\n    fp.write(s)\n\n',
  package_dir = {'': 'lib/python'},
  py_modules = ['cs.html'],
)
